@@ -1,9 +1,8 @@
 # Public API
-from .mahalanobis import geochemical_filter
+from .mahalanobis import mahalanobis_filter
 from .KDE import KDE, MD, iqr_one_peak
-from .formula_recalc import recalc
-from .formula_recalc import recalc_Fe
-
+from .formula_recalc import recalc, recalc_Fe
+from .filter import geoscore_filter, filter_fig
 
 try:
     from importlib.metadata import version as _v
